######################################################################
# ClearCase/ClearQuest Integration Trigger configuration 
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2001, 2008. All Rights Reserved.
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp.
# 
# This file contains basic configuration parameters for the CQCC
# integration that are modified by local administrators to define
# policy choices and describe local ClearQuest schema changes.
#    
# Each group of configuration parameters references the relevant 
# section or subsection of the online help which provides detailed
# information on when and how to use the parameters. 
# 
# To access the current online documentation, do the following: 
#     cleartool man contents
#     select "Viewing Rational ClearCase manuals online"
#     select the "Guide to Managing Software Projects" 
#     go to Chapter 13, "Setting up the base ClearCase integration
#                        with Rational ClearQuest"
# 
# For central cache management and error logging documentation, 
#     see Clearcase 7.0.1 release notes
# 
# On Windows, you can also use the menus to get to online help:
# Start/Programs/IBM Rational Software/IBM Rational ClearCase/Online Help
# 
# NOTE: If config.pl is modified, it will not be overwritten when
# ClearCase is upgraded. Therefore it may not contain the latest
# parameters and descriptions. A second copy of the file
# (configTemplate.pl) is available in the same directory and should be
# overwritten when upgrades are installed and if changes have been
# made. Always check configTemplate.pl for the latest configuration
# information.
# 
# NOTE: If you need to save non-ASCII strings in this file as UTF8
# you will need to add "use utf8;" in the next section and save the 
# file as UTF8 using a UTF8 friendly editor. See the documentation 
# section on "About codepage conversion" for more information. 

######################################################################
# Standard setup calls - DON'T CHANGE THIS SECTION
######################################################################

# These classes define the top level trigger object (TriggerCQCC),
# and support for parameters and CQSchemas. 

use CQCC::TriggerCQCC;
use CQCC::Parm;
use CQCC::CQSchema;   

# These two calls invoke your configuration subroutine below
# then start the trigger.

&ConfigureTrigger();
&TriggerMain();

######################################################################
# Configuration Parameters - MAKE CHANGES BELOW
# 
# Note: Configuration parameters marked as [ENV] are also available 
# as local environment variables with the same names. [DEFAULT] 
# shows the default settings used. Make sure to uncomment any 
# optional parameters you are activating (remove the leading #).
######################################################################

sub ConfigureTrigger {
    # Temp variable for a schema object, may be reused
    my $s;     

    ############################################################
    # Section: Establishing the Rational ClearQuest Web Interface    
    # These are only required if you are using the Web interface
    # to ClearQuest instead of the native ClearQuest client. 
    ############################################################

    #------------------------------
    # CQCC_CQWEB_VERSION: [ENV] [DEFAULT: "2.0"]
    # Values: "1.0" for CQWeb ASP, "2.0" for CQWebJava
    # &SetConfigParm("CQCC_CQWEB_VERSION", "1.0");

    #------------------------------
    # CQCC_SERVER: [ENV]              [DEFAULT: (undef)]
    # Note: Optional port is specified on host name as in "myhost:80"
    # &SetConfigParm("CQCC_SERVER", "<server>");

    #------------------------------
    # CQCC_SERVERROOT: [ENV]          [DEFAULT: "cqweb"]
    # &SetConfigParm("CQCC_SERVERROOT", "cqweb");

    #------------------------------
    # CQCC_SERVER_SSL:                [DEFAULT: "FALSE"]
    # &SetConfigParm("CQCC_SERVER_SSL", "TRUE");

    #------------------------------
    # CQCC_CQWEB_ONLY:                [DEFAULT: "FALSE"]
    # &SetConfigParm("CQCC_CQWEB_ONLY", "TRUE");

    ############################################################
    # Section: Defining the Rational ClearQuest user database
    # and database set
    ############################################################

    #------------------------------
    # CQCC_DATABASE_ENTITY_LIST:     [DEFAULT: "SAMPL: defect"]

    &SetConfigParm("CQCC_DATABASE_ENTITY_LIST",
                   "SAMPL: defect");

    #------------------------------
    # CQCC_DATABASE_SET [ENV]:    [DEFAULT: CQ_DBSET environment var]
    # &SetConfigParm("CQCC_DATABASE_SET", "<db_set_name>");

    #------------------------------
    # CQCC_WEB_DATABASE_SET [ENV]:    [DEFAULT: (undef)]
    # &SetConfigParm("CQCC_WEB_DATABASE_SET", "<db_set_name>");

    ############################################################
    # Section: Establishing the schemas
    ############################################################

    #------------------------------
    # CQSchema(s): 

    $s = &DefineCQSchema(NAME=>"MainSchema",
                         ENTITY_LIST => "defect",
                         RESTRICTIONS => "STANDARD");

    $s->ChangeFieldMap(OWNER => "Owner",
                       STATE => "State",
                       ID => "id",  #Note: ID shouldn't need to change
                       HEADLINE => "Headline",
                       PRIORITY => "Priority",  
                       SEVERITY => "Severity",
                       RATL_MASTERSHIP => "ratl_mastership",

                       # Other mappable names
                       QUERY_STATES => "Submitted,Assigned,Opened",
                       MODIFY => "modify"
                       );

    $s->SetQuery("STANDARD", 
                 "<OWNER> eq <*USER*>",
                 "<STATE> in <QUERY_STATES>");

    $s->SetResultSet("STANDARD",
                     "<ID>,<STATE>,<PRIORITY>,<SEVERITY>,<HEADLINE>",
                     "%s %-9.9s %1.1s %1.1s %-45.45s");

    ##################################################
    # Section: Establishing Rational ClearCase Multisite support
    ##################################################

    #------------------------------
    # CQCC_MULTISITE:                 [DEFAULT: "FALSE"]
    # &SetConfigParm("CQCC_MULTISITE", "TRUE");

    #------------------------------
    # CQCC_REPLICA_NAME [ENV]:        [DEFAULT: (undef)]
    # &SetConfigParm("CQCC_REPLICA_NAME", "<replica_name>");

    ############################################################
    # Section: Making policy choices
    # Subsection: Allowing multiple associations
    ############################################################

    #------------------------------
    # CQCC_MULTIPLE_ASSOCS:           [DEFAULT: TRUE]
    # &SetConfigParm("CQCC_MULTIPLE_ASSOCS", "FALSE");

    ############################################################
    # Subsection: Controlling query usage
    ############################################################

    #------------------------------
    # CQCC_QUERY_ENABLE:              [DEFAULT: LOCAL ]
    # Values: OFF (none), CQ (ClearQuest only), LOCAL(config file), BOTH
    # &SetConfigParm("CQCC_QUERY_ENABLE", "BOTH");

    #------------------------------
    # CQCC_QUERY_FILTER:              [DEFAULT: "" ]
    # &SetConfigParm("CQCC_QUERY_FILTER", "Public Queries");

    ############################################################
    # Subsection: Allowing use of the graphical user interface (GUI)
    ############################################################

    #------------------------------
    # CQCC_GUI_ENABLE [ENV]:          [DEFAULT: "ON"]
    # Values: OFF(no GUI), ON(In GUI environment), ALWAYS
    # &SetConfigParm("CQCC_GUI_ENABLE", "OFF");

    ############################################################
    # Subsection: Forcing checkin success before committing 
    # associations
    ############################################################

    #------------------------------
    # CQCC_POSTCHECKIN_COMMIT:        [DEFAULT: FALSE]
    # &SetConfigParm("CQCC_POSTCHECKIN_COMMIT", "TRUE");

    ############################################################
    # Section: Enhancing performance
    # Subsection: Using the association batch feature
    ############################################################

    #------------------------------
    # CQCC_ASSOC_BATCH_ENABLE: [ENV]   [DEFAULT: "FALSE"]
    # Values: FALSE (off), TRUE (on), AUTOFLUSH(post after each file)
    # &SetConfigParm("CQCC_ASSOC_BATCH_ENABLE", "TRUE");

    #------------------------------
    # CQCC_ASSOC_BATCH_SERIES: [ENV]    [DEFAULT: FALSE]
    # End user environment variable only
    # Windows: set CQCC_ASSOC_BATCH_SERIES=TRUE
    # UNIX: setenv CQCC_ASSOC_BATCH_SERIES TRUE

    #------------------------------
    # CQCC_ASSOC_BATCH_CONFIRM: [ENV]   [DEFAULT: OFF]
    # Values: OFF, MULTIPLE(multiple checkins only), ALWAYS(all operations)
    # &SetConfigParm("CQCC_ASSOC_BATCH_CONFIRM", "MULTIPLE");

    #------------------------------
    # CQCC_RESTRICTIONS_TIMEOUT: [ENV] [DEFAULT: 300]
    # &SetConfigParm("CQCC_RESTRICTIONS_TIMEOUT, 0);

    ############################################################
    # Subsection: Use CLEARCASE_XPN for mkhlink
    # Note: This feature should be enabled only if the mkhlink
    # fails.  This is used for windows only.  This option may
    # be needed when accessing unix VOBs via the MVFS drive and
    # other non integration preop triggers are firing.
    # Turning on this option may lead to the wrong file being
    # linked if there are multiple checkouts of that file.
    # A safer option is to mount the view instead of using the
    # MVFS drive or just turning this option on as needed by
    # by setting the environment variable.
    ############################################################

    #------------------------------
    # CQCC_MKHLINK_CCXPN:  [ENV]   [DEFAULT: FALSE]
    # &SetConfigParm("CQCC_MKHLINK_CCXPN", "TRUE");

    ############################################################
    # Subsection: Controlling and using automatic associations
    ############################################################

    #------------------------------
    # CQCC_AUTO_ASSOCIATE_ENABLE:            [DEFAULT: "TRUE"]
    # &SetConfigParm("CQCC_AUTO_ASSOCIATE_ENABLE", "FALSE");
    
    #------------------------------
    # CQCC_AUTO_ASSOCIATE: [ENV]       [DEFAULT: ""]
    # End user environment variable only
    # Windows: set CQCC_AUTO_ASSOCIATE="<buglist>"
    # UNIX: setenv CQCC_AUTO_ASSOCIATE "<buglist>"
    # where multiple bugs are separated by commas

    #------------------------------
    # CQCC_COMMENT_PATTERN:             [DEFAULT: ""]
    # &SetConfigParm("CQCC_COMMENT_PATTERN", "BUGS:\\[(\\S+)\\]");

    ############################################################
    # Section: Centralized Cache Management
    # Central Caching documentation is in the 7.0.1 Release Notes
    # 
    # CQCC_CACHE_ROOT must be set up for CCRC servers
    # and Clearcase Scheduler task enabled
    ############################################################

    #------------------------------
    # CQCC_CACHE_ROOT:                [DEFAULT: ""]
    # See documentation for more information on using this and 
    # setting up the cache manager scheduler task
    # &SetConfigParm("CQCC_CACHE_ROOT", "<central-cache-dir-root>");

    #------------------------------
    # CQCC_CACHE_MGMT:                [DEFAULT: ""]                   
    # Advanced options: See documentation for more information
    # &SetConfigParm("CQCC_CACHE_MGMT", "<cache_mgmt_options>");

    #------------------------------
    # CQCC_SESSION_ID: [ENV]          [DEFAULT: "main"]
    # End user environment variable only
    # Windows: set CQCC_SESSION_ID=identifier
    # UNIX: setenv CQCC_SESSION_ID identifier
    # 
    # &SetConfigParm("CQCC_SESSION_ID", "<session-name>");
    
    ############################################################
    # Section: Debugging and analyzing operations
    ############################################################

    #------------------------------
    # CQCC_LOG_ERRORS: [ENV]          [DEFAULT: ""]
    # Values: "", INFO, WARN, ERROR, FATAL
    # &SetConfigParm("CQCC_LOG_ERRORS", "ERROR");

    #------------------------------
    # CQCC_DEBUG: [ENV]               [DEFAULT: 0]
    # Values: 0 (off), 1(basic), 2(details)
    # &SetConfigParm("CQCC_DEBUG", "1");

    #------------------------------
    # CQCC_TIMER: [ENV]               [DEFAULT: 0]
    # &SetConfigParm("CQCC_TIMER", "1");

    #------------------------------
    # CQCC_LOG_OUTPUT: [ENV]          [DEFAULT: OFF]
    # Values: OFF, OVERWRITE, APPEND, 
    #    OVERWRITE_THREADS, APPEND_THREADS
    # &SetConfigParm("CQCC_LOG_OUTPUT", "OVERWRITE");
}
